import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import 'package:syncrow_web/pages/device_managment/shared/navigate_home_grid_view.dart';
import 'package:syncrow_web/pages/space_management_v2/main_module/widgets/space_management_body.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/community_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/space_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/params/load_communities_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/services/communities_service.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/bloc/communities_bloc.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/presentation/communities_tree_selection_bloc/communities_tree_selection_bloc.dart';
import 'package:syncrow_web/utils/theme/responsive_text_theme.dart';
import 'package:syncrow_web/web_layout/web_scaffold.dart';

class SpaceManagementPage extends StatelessWidget {
  const SpaceManagementPage({super.key});

  @override
  Widget build(BuildContext context) {
    return MultiBlocProvider(
      providers: [
        BlocProvider(
          create: (context) => CommunitiesBloc(
            communitiesService: _FakeCommunitiesService(),
          )..add(const LoadCommunities(LoadCommunitiesParam())),
        ),
        BlocProvider(create: (context) => CommunitiesTreeSelectionBloc()),
      ],
      child: WebScaffold(
        appBarTitle: Text(
          'Space Management',
          style: ResponsiveTextTheme.of(context).deviceManagementTitle,
        ),
        enableMenuSidebar: false,
        centerBody: Text(
          'Community Structure',
          style: Theme.of(context).textTheme.bodyLarge!.copyWith(
                fontWeight: FontWeight.bold,
              ),
        ),
        rightBody: const NavigateHomeGridView(),
        scaffoldBody: const SpaceManagementBody(),
      ),
    );
  }
}

class _FakeCommunitiesService extends CommunitiesService {
  @override
  Future<List<CommunityModel>> getCommunity(LoadCommunitiesParam param) async {
    return Future.delayed(
      const Duration(seconds: 1),
      () => [
        const CommunityModel(
          uuid: '1',
          name: 'Community 1',
          spaces: [
            SpaceModel(
              uuid: '3',
              spaceName: 'Space 1',
              icon: 'assets/icons/space.png',
              children: [
                SpaceModel(
                  uuid: '4',
                  spaceName: 'Space 2',
                  icon: 'assets/icons/space.png',
                  children: [],
                  status: SpaceStatus.active,
                ),
              ],
              status: SpaceStatus.active,
            ),
          ],
        ),
        const CommunityModel(
          uuid: '2',
          name: 'Community 1',
          spaces: [],
        ),
      ],
    );
  }
}
