import 'package:dio/dio.dart';
import 'package:syncrow_web/pages/common/bloc/project_manager.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/models/community_model.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/params/load_communities_param.dart';
import 'package:syncrow_web/pages/space_management_v2/modules/communities/domain/services/communities_service.dart';
import 'package:syncrow_web/services/api/api_exception.dart';
import 'package:syncrow_web/services/api/http_service.dart';
import 'package:syncrow_web/utils/constants/api_const.dart';

class RemoteCommunitiesService implements CommunitiesService {
  const RemoteCommunitiesService(this._httpService);

  final HTTPService _httpService;

  static const _defaultErrorMessage = 'Failed to load communities';

  @override
  Future<List<CommunityModel>> getCommunity(LoadCommunitiesParam param) async {
    final projectUuid = await ProjectManager.getProjectUUID();
    if (projectUuid == null) throw APIException('Project UUID is not set');

    try {
      final allCommunities = <CommunityModel>[];
      await _httpService.get(
        path: await _makeUrl(),
        expectedResponseModel: (json) {
          final response = json as Map<String, dynamic>;
          final jsonData = response['data'] as List<dynamic>? ?? [];
          return jsonData
              .map(
                (jsonItem) => CommunityModel.fromJson(
                  jsonItem as Map<String, dynamic>,
                ),
              )
              .toList();
        },
      );

      return allCommunities;
    } on DioException catch (e) {
      final message = e.response?.data as Map<String, dynamic>?;
      final error = message?['error'] as Map<String, dynamic>?;
      final errorMessage = error?['error'] as String? ?? '';
      throw APIException(errorMessage);
    } catch (e) {
      final formattedErrorMessage = [_defaultErrorMessage, '$e'].join(': ');
      throw APIException(formattedErrorMessage);
    }
  }

  Future<String> _makeUrl() async {
    final projectUuid = await ProjectManager.getProjectUUID();
    if (projectUuid == null) throw APIException('Project UUID is required');
    return ApiEndpoints.getCommunityList.replaceAll('{projectId}', projectUuid);
  }
}
